@@ -7,7 +7,7 @@ use Carp;
 use Woothee::Util qw/update_map update_category update_version update_os update_os_version/;
 use Woothee::DataSet qw/dataset/;
 
-our $VERSION = "1.3.0";
+our $VERSION = "1.4.0";
 
 sub challenge_playstation {
     my ($ua, $result) = @_;
@@ -98,7 +98,7 @@ __END__
 
 Woothee::Appliance - part of Woothee
 
-For Woothee, see https://github.com/tagomoris/woothee
+For Woothee, see L<https://github.com/woothee/woothee>
 
 =head1 DESCRIPTION
 
