@@ -7,7 +7,7 @@ use Carp;
 use Woothee::Util qw/update_map update_category update_version update_os/;
 use Woothee::DataSet qw/dataset/;
 
-our $VERSION = "1.3.0";
+our $VERSION = "1.4.0";
 
 sub challenge_msie {
     my ($ua,$result) = @_;
@@ -29,6 +29,21 @@ sub challenge_msie {
     return 1;
 }
 
+sub challenge_vivaldi {
+    my ($ua, $result) = @_;
+
+    return 0 if index($ua, "Vivaldi/") < 0;
+
+    my $version = Woothee::DataSet->const('VALUE_UNKNOWN');
+
+    if ($ua =~ m{Vivaldi/([.0-9]+)}o) {
+        $version = $1;
+    }
+    update_map($result, dataset('Vivaldi'));
+    update_version($result, $version);
+    return 1;
+}
+
 sub challenge_safari_chrome { # and Opera(blink)
     my ($ua,$result) = @_;
 
@@ -169,7 +184,7 @@ __END__
 
 Woothee::Browser - part of Woothee
 
-For Woothee, see https://github.com/tagomoris/woothee
+For Woothee, see L<https://github.com/woothee/woothee>
 
 =head1 DESCRIPTION
 
