@@ -7,7 +7,7 @@ use Carp;
 use Woothee::Util qw/update_map update_category update_version update_os/;
 use Woothee::DataSet qw/dataset/;
 
-our $VERSION = "1.3.0";
+our $VERSION = "1.4.0";
 
 sub challenge_google {
     my ($ua,$result) = @_;
@@ -203,7 +203,7 @@ __END__
 
 Woothee::Crawler - part of Woothee
 
-For Woothee, see https://github.com/tagomoris/woothee
+For Woothee, see L<https://github.com/woothee/woothee>
 
 =head1 DESCRIPTION
 
