@@ -6,7 +6,7 @@ use Carp;
 
 use Woothee::DataSet;
 
-our $VERSION = "1.3.0";
+our $VERSION = "1.4.0";
 
 our (@ISA, @EXPORT_OK);
 BEGIN {
@@ -53,7 +53,7 @@ __END__
 
 Woothee::Util - part of Woothee
 
-For Woothee, see https://github.com/tagomoris/woothee
+For Woothee, see L<https://github.com/woothee/woothee>
 
 =head1 DESCRIPTION
 
